@@ -29,6 +29,8 @@ private:
 
     bool checkCollisionWithBoard();
 
+    void disableDisplayOff();
+
 private slots:
 
     void timeout();
@@ -42,6 +44,7 @@ private:
     Board* mBoard;
     Pair* mPair;
     QTimer* mTimer;
+    int mDisplayCounter;
 };
 
 #endif //GAMETHREAD_H_
